#include <cstdio>
#include <vector>
#include <map>
#include <algorithm>
using namespace std;

#define MOD 1000000007LL

struct Znum {
  long long value;
  Znum() : value(0) {}
  explicit Znum(long long v) {
    while (v < 0) v += MOD;
    value = v % MOD;
  }
  Znum operator+(const Znum& b) { return Znum(value + b.value); }
  Znum operator-(const Znum& b) { return Znum(value - b.value); }
  Znum operator*(const Znum& b) { return Znum(value * b.value); }
};

Znum arithsum(int n) { // -> 0+1+2+...+(n-1)
  return Znum(1LL * n * (n-1) / 2);
}

struct Tree {
  int N;
  vector<Znum> sumof;
  vector<bool> lazy;
  vector<long long> lazyval;
  vector<long long> lazyinc;

  void init(int size) {
    N = 1;
    while (N < size) N *= 2;
    sumof.resize(N * 2);
    lazy.resize(N * 2);
    lazyval.resize(N * 2);
    lazyinc.resize(N * 2);
  }

  Znum getsum(int from, int to) {
    Znum result = getsum(from, to, 1, 0, N);
//    fprintf(stderr, "getsum(%lld, %d, %d) = %lld\n", (long long)this, from, to, result.value);
    return result;
  }

  void set(int from, int to, long long fromval, long long inc) {
//    fprintf(stderr, "set(%lld, %d, %d, %lld, %lld)\n", (long long)this, from, to, fromval, inc);
    set(from, to, fromval, inc, 1, 0, N);
  }

  Znum getsum(int from, int to, int v, int vleft, int vright) {
    if (from >= vright || to <= vleft) return Znum(0);
    if (from <= vleft && to >= vright) return sumof[v];
    int vmid = (vleft + vright) / 2;
    if (lazy[v]) {
      makelazy(lazyval[v], lazyinc[v], 2*v, vleft, vmid);
      makelazy(lazyval[v] + lazyinc[v] * (vmid - vleft), lazyinc[v], 2*v+1, vmid, vright);
      lazy[v] = false;
    }
    return getsum(from, to, 2*v, vleft, vmid) + getsum(from, to, 2*v+1, vmid, vright);
  }

  void set(int from, int to, long long fromval, long long inc, int v, int vleft, int vright) {
    if (from >= vright || to <= vleft) return;
    if (from <= vleft && to >= vright) {
      makelazy(fromval + inc * (vleft - from), inc, v, vleft, vright);
      return;
    }
    int vmid = (vleft + vright) / 2;
    set(from, to, fromval, inc, 2*v, vleft, vmid);
    set(from, to, fromval, inc, 2*v+1, vmid, vright);
    lazy[v] = false;
    sumof[v] = sumof[2*v] + sumof[2*v+1];
  }

  void makelazy(long long val, long long inc, int v, int vleft, int vright) {
    lazy[v] = true;
    lazyval[v] = val;
    lazyinc[v] = inc;
    int mylen = vright - vleft;
    sumof[v] = Znum(val) * Znum(mylen) + Znum(inc) * arithsum(mylen);
  }
};

struct Case {
  int N, Q;
  vector<int> parent;
  vector<int> depth;
  vector<int> heavyancestor;
  map<int, Tree> trees;

  void readinput() {
    scanf("%d%d", &N, &Q);

    parent.resize(N);
    depth.resize(N);
    heavyancestor.resize(N);

    vector<int> mass(N);
    vector<vector<int>> edges(N);
    vector<int> heavychild(N, -1);
    vector<int> lengthbelow(N);
    vector<int> preorder;

    fprintf(stderr, "initialized %d %d\n", N, Q);

    for (int i = 0; i < N-1; i++) {
      int a, b;
      scanf("%d%d", &a, &b);
      a--; b--;
      edges[a].push_back(b);
      edges[b].push_back(a);
    }
    fprintf(stderr, "read %d %d\n", N, Q);

    vector<int> dfs;
    dfs.push_back(0);
    parent[0] = -1;
    while (!dfs.empty()) {
      int v = dfs.back();
      dfs.pop_back();
      preorder.push_back(v);
      for (int u : edges[v]) if (u != parent[v]) {
        parent[u] = v;
        depth[u] = depth[v] + 1;
        dfs.push_back(u);
      }
    }
    fprintf(stderr, "dfs %d %d\n", N, Q);

    for (int i = N-1; i >= 0; i--) {
      int v = preorder[i];
      mass[v] = 1;
      int heaviest = -1;
      for (int u : edges[v]) if (u != parent[v]) {
        mass[v] += mass[u];
        if (heaviest == -1 || mass[u] > mass[heaviest]) heaviest = u;
      }
      heavychild[v] = heaviest;
    }

    edges.clear();
    edges.shrink_to_fit();

    for (int v = 0; v < N; v++) heavyancestor[v] = v;
    for (int i = 0; i < N; i++) {
      int v = preorder[i];
      if (heavychild[v] != -1) heavyancestor[heavychild[v]] = heavyancestor[v];
    }
    for (int i = N-1; i >= 0; i--) {
      int v = preorder[i];
      lengthbelow[v] = 1 + (heavychild[v] != -1 ? lengthbelow[heavychild[v]] : 0);
      if (v == heavyancestor[v]) {
        trees[v].init(lengthbelow[v]);
      }
    }
    fprintf(stderr, "dfs2 %d %d\n", N, Q);
  }

  void solve() {
    readinput();

    Znum total_answer(0);

    long long now = 0;
    for (int qid = 1; qid <= Q; qid++) {
      int a, b, c;
      scanf("%d%d%d", &a, &b, &c);
      a--; b--;

      // heavy-light decomposition.
      vector<pair<int,int>> sega, segb;
      while (a != b) {
        if (heavyancestor[a] == heavyancestor[b]) {
          if (depth[a] > depth[b]) {
            sega.push_back({a, b});
            a = b;
          } else {
            segb.push_back({b, a});
            b = a;
          }
        } else {
          bool doa = depth[heavyancestor[a]] > depth[heavyancestor[b]];
          int& m = doa ? a : b;
          (doa ? sega : segb).push_back({m, parent[heavyancestor[m]]});
          m = parent[heavyancestor[m]];
        }
      }
      reverse(segb.begin(), segb.end());

      // find the answer.
      Znum answer(0);
      int len = 0;
      for (const auto& seg : {&sega, &segb}) {
        for (const auto& p : *seg) {
          int ancestor = heavyancestor[p.first];
          int base = depth[ancestor] - 1;
          answer = answer + trees[ancestor].getsum(depth[p.second] - base, depth[p.first] - base);
          len += depth[p.first] - depth[p.second];
        }
      }
      answer = Znum(now) * Znum(len) - answer + Znum(c) * arithsum(len);

      // update snow.
      for (const auto& p : sega) {
        int ancestor = heavyancestor[p.first];
        int base = depth[ancestor] - 1;
        now += c * (depth[p.first] - depth[p.second]);
        trees[ancestor].set(depth[p.second] - base, depth[p.first] - base, now-c, -c);
      }
      for (const auto& p : segb) {
        int ancestor = heavyancestor[p.first];
        int base = depth[ancestor] - 1;
        trees[ancestor].set(depth[p.second] - base, depth[p.first] - base, now, c);
        now += c * (depth[p.first] - depth[p.second]);
      }

//      fprintf(stderr, "%lld\n", answer.value);
      total_answer = total_answer + Znum(qid) * answer;
    }
    fprintf(stderr, "finished %d %d\n", N, Q);

    printf("%lld\n", total_answer.value);
  }
};

int main() {
  int T;
  scanf("%d", &T);
  while (T--) {
    Case().solve();
  }
}
